@@ -2045,7 +2045,7 @@ bool KBiffPop::authenticate(const TQString& user, const TQString& pass)
         TQCString digest;
 
         KMD5 md5(chall_apop);
-        md5.update(pass);
+        md5.update(pass.utf8());
 
         digest = md5.hexDigest();
         
